@@ -302,7 +302,7 @@ ecp_draw (ECellView *ecv, GdkDrawable *drawable,
 			       &rect, canvas, "ecellpopup",
 			       rect.x, rect.y, rect.width, rect.height);
 		gtk_paint_arrow (canvas->style, drawable,
-				 GTK_STATE_NORMAL, shadow,
+				 GTK_STATE_NORMAL, GTK_SHADOW_NONE,
 				 &rect, canvas, NULL,
 				 GTK_ARROW_DOWN, TRUE,
 				 rect.x + E_CELL_POPUP_ARROW_XPAD,
