@@ -31,10 +31,10 @@ extern "C" {
 #endif /* __cplusplus */
 
 #define E_SELECTION_MODEL_SIMPLE_TYPE        (e_selection_model_simple_get_type ())
-#define E_SELECTION_MODEL_SIMPLE(o)          (GTK_CHECK_CAST ((o), E_SELECTION_MODEL_SIMPLE_TYPE, ESelectionModelSimple))
-#define E_SELECTION_MODEL_SIMPLE_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_SELECTION_MODEL_SIMPLE_TYPE, ESelectionModelSimpleClass))
-#define E_IS_SELECTION_MODEL_SIMPLE(o)       (GTK_CHECK_TYPE ((o), E_SELECTION_MODEL_SIMPLE_TYPE))
-#define E_IS_SELECTION_MODEL_SIMPLE_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_SELECTION_MODEL_SIMPLE_TYPE))
+#define E_SELECTION_MODEL_SIMPLE(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_SELECTION_MODEL_SIMPLE_TYPE, ESelectionModelSimple))
+#define E_SELECTION_MODEL_SIMPLE_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_SELECTION_MODEL_SIMPLE_TYPE, ESelectionModelSimpleClass))
+#define E_IS_SELECTION_MODEL_SIMPLE(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_SELECTION_MODEL_SIMPLE_TYPE))
+#define E_IS_SELECTION_MODEL_SIMPLE_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_SELECTION_MODEL_SIMPLE_TYPE))
 
 typedef struct {
 	ESelectionModelArray parent;
@@ -46,7 +46,7 @@ typedef struct {
 	ESelectionModelArrayClass parent_class;
 } ESelectionModelSimpleClass;
 
-GtkType                e_selection_model_simple_get_type       (void);
+GType                  e_selection_model_simple_get_type       (void);
 ESelectionModelSimple *e_selection_model_simple_new            (void);
 
 void                   e_selection_model_simple_insert_rows     (ESelectionModelSimple *esms,
